@@ -1,9 +1,14 @@
+import sys
+import os
+sys.path.append(os.path.dirname(
+    os.path.dirname(os.path.abspath(__file__))))
+
 import numpy as np
 import scipy as sp 
 import sympy as sy
 import matplotlib.pyplot as plt
 from sklearn.cluster import KMeans
-import optimize as op
+import qufit.optimize as op
 import math
 
 
